# Stage: Effective Area

The purpose of this stage is the conversion of the incoming neutrino flux at the detector into an event count. This includes the interaction of the neutrinos, as well as the triggering and event selection criteria (filters), so that the resulting flux is at _analysis level_. 

The total event __counts__ in each bin is simply calculated as the product of 

![Events](images/events.png)
